@@ -31,4 +31,9 @@ def kaufman(token):
     url = "https://spawnerapi.com/kaufman/" + token
     response = requests.get(url).json()
     return response
+
+def momentum(token): 
+    url = "https://spawnerapi.com/momentum/" + ticker + "/" + token
+    response = requests.get(url).text
+    return response
                 
\ No newline at end of file
