@@ -11,7 +11,7 @@ def answer(question):
         r = requests.post(url, headers=headers, data=json.dumps(trade_list))
         content = r.text
         df = pd.read_json(content, orient='records')
-        df = df.drop(columns=['chart_type', 'condensed_data'])
+        df = df.drop(columns=['chart_type', 'condensed_data', 'data'])
         return df
     except: 
         return 'I am not smart enough to answer that question. Try again.'
\ No newline at end of file
